==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs(
    public val all:
    Output<WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? = null,
    public val excludedCookies: Output<List<String>>? = null,
    public val includedCookies: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs> {
    override fun toJava():
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .excludedCookies(excludedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedCookies(includedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs].
 */
@PulumiTagMarker
public class WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? = null

    private var excludedCookies: Output<List<String>>? = null

    private var includedCookies: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("lhtvygbqjagwtfah")
    public suspend
    fun all(`value`: Output<WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("kjkytjmlyniryxkw")
    public suspend fun excludedCookies(`value`: Output<List<String>>) {
        this.excludedCookies = value
    }

    @JvmName("gkhrqovvynhvywsu")
    public suspend fun excludedCookies(vararg values: Output<String>) {
        this.excludedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("dkjywllhvyhfsxce")
    public suspend fun excludedCookies(values: List<Output<String>>) {
        this.excludedCookies = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("xmymcplruaacloov")
    public suspend fun includedCookies(`value`: Output<List<String>>) {
        this.includedCookies = value
    }

    @JvmName("jaafflsowlggouqt")
    public suspend fun includedCookies(vararg values: Output<String>) {
        this.includedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("hedstjhqohphkyms")
    public suspend fun includedCookies(values: List<Output<String>>) {
        this.includedCookies = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("nupgqenndieadchv")
    public suspend
    fun all(`value`: WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("grsnpxvkoijmnhkc")
    public suspend
    fun all(argument: suspend WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("shoiuhfbunsthkjb")
    public suspend fun excludedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("sobpqhlglnggikuh")
    public suspend fun excludedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param value
     */
    @JvmName("xcwasrhljvbejeqj")
    public suspend fun includedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("xfpcybdjhopwirsp")
    public suspend fun includedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    internal fun build(): WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs =
        WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs(
            all = all,
            excludedCookies = excludedCookies,
            includedCookies = includedCookies,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs(
    public val all: Output<WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? = null,
    public val excludedCookies: Output<List<String>>? = null,
    public val includedCookies: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .excludedCookies(excludedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedCookies(includedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs].
 */
@PulumiTagMarker
public class WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? = null

    private var excludedCookies: Output<List<String>>? = null

    private var includedCookies: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("oocaasodffvpompo")
    public suspend fun all(`value`: Output<WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("lnxrrmrxfipbtnhl")
    public suspend fun excludedCookies(`value`: Output<List<String>>) {
        this.excludedCookies = value
    }

    @JvmName("pbeydhprwggvbdsh")
    public suspend fun excludedCookies(vararg values: Output<String>) {
        this.excludedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("gelwymoxanvqgbxu")
    public suspend fun excludedCookies(values: List<Output<String>>) {
        this.excludedCookies = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("mnucltnbgccpuqgi")
    public suspend fun includedCookies(`value`: Output<List<String>>) {
        this.includedCookies = value
    }

    @JvmName("iokxbfvvdjhedxod")
    public suspend fun includedCookies(vararg values: Output<String>) {
        this.includedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("vpeqnvxlxpbmagup")
    public suspend fun includedCookies(values: List<Output<String>>) {
        this.includedCookies = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("hlflputlynliarpa")
    public suspend fun all(`value`: WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("lqanupaoppfoshlb")
    public suspend fun all(argument: suspend WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("xlweuhbvrboobfka")
    public suspend fun excludedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("aooayevvhafavqkc")
    public suspend fun excludedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param value
     */
    @JvmName("xbouoebmwqswpgxr")
    public suspend fun includedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("vckdgjqonfefimjq")
    public suspend fun includedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    internal fun build(): WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs =
        WebAclRuleStatementByteMatchStatementFieldToMatchCookiesMatchPatternArgs(
            all = all,
            excludedCookies = excludedCookies,
            includedCookies = includedCookies,
        )
}
